/*
   Copyright (c) 2020 LinkedIn Corp.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package com.linkedin.darkcluster;

import com.linkedin.d2.DarkClusterConfig;
import com.linkedin.d2.DarkClusterStrategyName;
import com.linkedin.d2.DarkClusterStrategyNameArray;
import com.linkedin.darkcluster.api.DarkClusterStrategy;

/**
 * Contains helper methods to create valid {@link DarkClusterConfig}s for different {@link DarkClusterStrategy}s.
 */
public class DarkClusterTestUtil
{
  /**
   * This creates the RelativeTrafficMultiplierConfig, which justs consists of
   * setting the multiplier.
   */
  public static DarkClusterConfig createRelativeTrafficMultiplierConfig(float multiplier)
  {
    DarkClusterStrategyNameArray darkClusterStrategyArray = new DarkClusterStrategyNameArray();
    darkClusterStrategyArray.add(DarkClusterStrategyName.RELATIVE_TRAFFIC);
    return new DarkClusterConfig()
      .setDarkClusterStrategyPrioritizedList(darkClusterStrategyArray)
      .setMultiplier(multiplier);
  }
}
